@@ -9,13 +9,25 @@ import functools
 import warnings
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Any, Dict, Hashable, List, Optional, Set, Tuple, TypeVar, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Hashable,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    TypeVar,
+    Union,
+)
 
 import numpy
 import xarray
 from affine import Affine
 
-from ._interop import have
+from ._interop import have, is_dask_collection
+from ._rgba import colorize, to_rgba
 from .crs import CRS, CRSError, SomeCRS, norm_crs_or_error
 from .geobox import Coordinate, GeoBox
 from .geom import Geometry
@@ -23,12 +35,16 @@ from .math import affine_from_axis
 from .overlap import compute_output_geobox
 from .types import Resolution, resxy_
 
+# pylint: disable=import-outside-toplevel
 if have.rasterio:
-    from ._cog import to_cog, write_cog  # pylint: disable=import-outside-toplevel
+    from ._cog import to_cog, write_cog
+    from ._compress import compress
+    from ._map import add_to
     from .warp import rio_reproject
 
 XarrayObject = Union[xarray.DataArray, xarray.Dataset]
 XrT = TypeVar("XrT", xarray.DataArray, xarray.Dataset)
+F = TypeVar("F", bound=Callable)
 
 _DEFAULT_CRS_COORD_NAME = "spatial_ref"
 
@@ -320,18 +336,18 @@ def _locate_geo_info(src: XarrayObject) -> GeoState:
     return GeoState(spatial_dims=sdims, transform=transform, crs=crs, geobox=geobox)
 
 
-def _wrap_op(method):
+def _wrap_op(method: F) -> F:
     @functools.wraps(method, assigned=("__doc__",))
     def wrapped(*args, **kw):
         # pylint: disable=protected-access
         _self, *rest = args
         return method(_self._xx, *rest, **kw)
 
-    return wrapped
+    return wrapped  # type: ignore
 
 
 def xr_reproject(
-    src: xarray.DataArray,
+    src: Any,
     how: Union[SomeCRS, GeoBox],
     *,
     resampling: Union[str, int] = "nearest",
@@ -343,43 +359,62 @@ def xr_reproject(
 
     This method uses :py:mod:`rasterio`.
     """
+    assert isinstance(src, xarray.DataArray)
+
     if have.rasterio is False:
         raise RuntimeError(
             "Please install `rasterio` to use this method"
         )  # pragma: nocover
 
-    assert isinstance(src.odc, ODCExtension)  # for mypy sake
+    assert isinstance(src.odc, ODCExtensionDa)  # for mypy sake
+    src_gbox = src.odc.geobox
 
-    if src.odc.geobox is None:
-        raise ValueError("Can not reproject non-georestered array.")
+    if src_gbox is None:
+        raise ValueError("Can not reproject non-georegistered array.")
 
     if isinstance(how, GeoBox):
         dst_geobox = how
     else:
         dst_geobox = src.odc.output_geobox(how)
 
-    dst_shape = (*src.shape[:-2], *dst_geobox.shape)
+    if is_dask_collection(src):
+        raise NotImplementedError("Dask inputs are not yet supported.")
+
+    # compute destination shape by replacing spatial dimensions shape
+    ydim = src.odc.ydim
+    assert ydim + 1 == src.odc.xdim
+    dst_shape = (*src.shape[:ydim], *dst_geobox.shape, *src.shape[ydim + 2 :])
+
     dst = numpy.empty(dst_shape, dtype=src.dtype)
-    nodata = src.attrs.get("nodata", None)
+    src_nodata = src.attrs.get("nodata", None)
     if dst_nodata is None:
-        dst_nodata = nodata
+        dst_nodata = src_nodata
 
     dst = rio_reproject(
         src.values,
         dst,
-        src.odc.geobox,
+        src_gbox,
         dst_geobox,
         resampling=resampling,
-        src_nodata=nodata,
+        src_nodata=src_nodata,
         dst_nodata=dst_nodata,
+        ydim=ydim,
         **kw,
     )
 
     attrs = src.attrs.copy()
-    attrs.pop("nodata", None)
-    time = getattr(src, "time", None)
+    if dst_nodata is None:
+        attrs.pop("nodata", None)
+    else:
+        attrs.update(nodata=dst_nodata)
 
-    return wrap_xr(dst, dst_geobox, nodata=dst_nodata, attrs=attrs, time=time)
+    # new set of coords (replace x,y dims)
+    coords = dict((k, v) for k, v in src.coords.items() if k not in src.dims)
+    coords.update(xr_coords(dst_geobox))
+
+    dims = (*src.dims[:ydim], *dst_geobox.dimensions, *src.dims[ydim + 2 :])
+
+    return xarray.DataArray(dst, coords=coords, dims=dims, attrs=attrs)
 
 
 class ODCExtension:
@@ -405,17 +440,19 @@ class ODCExtension:
 
     @property
     def crs(self) -> Optional[CRS]:
+        """Query :py:class:`~odc.geo.crs.CRS`."""
         return self._state.crs
 
     @property
     def geobox(self) -> Optional[GeoBox]:
+        """Query :py:class:`~odc.geo.geobox.GeoBox`."""
         return self._state.geobox
 
     def output_geobox(self, crs: SomeCRS, **kw) -> GeoBox:
         """
         Compute geobox of this data in other projection.
 
-        ..see-also:: :py:meth:`odc.geo.overlap.compute_output_geobox`
+        ..seealso:: :py:meth:`odc.geo.overlap.compute_output_geobox`
         """
         gbox = self.geobox
         if gbox is None:
@@ -423,6 +460,14 @@ class ODCExtension:
 
         return compute_output_geobox(gbox, crs, **kw)
 
+    def map_bounds(self) -> Tuple[Tuple[float, float], Tuple[float, float]]:
+        """See :py:meth:`odc.geo.geobox.GeoBox.map_bounds`."""
+        gbox = self.geobox
+        if gbox is None:
+            raise ValueError("Not geo registered")
+
+        return gbox.map_bounds()
+
 
 @xarray.register_dataarray_accessor("odc")
 class ODCExtensionDa(ODCExtension):
@@ -438,15 +483,34 @@ class ODCExtensionDa(ODCExtension):
     def uncached(self) -> "ODCExtensionDa":
         return ODCExtensionDa(self._xx)
 
+    @property
+    def ydim(self) -> int:
+        """Index of the Y dimension."""
+        if (sdims := self.spatial_dims) is not None:
+            return self._xx.dims.index(sdims[0])
+        raise ValueError("Can't locate spatial dimensions")
+
+    @property
+    def xdim(self) -> int:
+        """Index of the X dimension."""
+        if (sdims := self.spatial_dims) is not None:
+            return self._xx.dims.index(sdims[1])
+        raise ValueError("Can't locate spatial dimensions")
+
     def assign_crs(
         self, crs: SomeCRS, crs_coord_name: str = _DEFAULT_CRS_COORD_NAME
     ) -> xarray.DataArray:
+        """See :py:meth:`odc.geo.xr.assign_crs`."""
         return assign_crs(self._xx, crs=crs, crs_coord_name=crs_coord_name)
 
+    colorize = _wrap_op(colorize)
+
     if have.rasterio:
         write_cog = _wrap_op(write_cog)
         to_cog = _wrap_op(to_cog)
+        compress = _wrap_op(compress)
         reproject = _wrap_op(xr_reproject)
+        add_to = _wrap_op(add_to)
 
 
 @xarray.register_dataset_accessor("odc")
@@ -468,6 +532,18 @@ class ODCExtensionDs(ODCExtension):
     ) -> xarray.Dataset:
         return assign_crs(self._ds, crs=crs, crs_coord_name=crs_coord_name)
 
+    def to_rgba(
+        self,
+        bands: Optional[Tuple[str, str, str]] = None,
+        *,
+        vmin: Optional[float] = None,
+        vmax: Optional[float] = None,
+    ) -> xarray.DataArray:
+        return to_rgba(self._ds, bands=bands, vmin=vmin, vmax=vmax)
+
+
+ODCExtensionDs.to_rgba.__doc__ = to_rgba.__doc__
+
 
 def _xarray_geobox(xx: XarrayObject) -> Optional[GeoBox]:
     if isinstance(xx, xarray.DataArray):
