@@ -24,7 +24,7 @@ from .geom import (
     point,
     polygon_from_transform,
 )
-from .math import clamp, is_affine_st, is_almost_int, snap_grid
+from .math import clamp, is_affine_st, is_almost_int, resolution_from_affine, snap_grid
 from .roi import Tiles as RoiTiles
 from .roi import align_up, polygon_path, roi_normalise, roi_shape
 from .types import (
@@ -39,7 +39,6 @@ from .types import (
     SomeShape,
     iyx_,
     res_,
-    resxy_,
     shape_,
     xy_,
 )
@@ -91,7 +90,7 @@ class GeoBox:
         crs: MaybeCRS = None,
         *,
         tight: bool = False,
-        shape: Optional[SomeShape] = None,
+        shape: Union[SomeShape, int, None] = None,
         resolution: Optional[SomeResolution] = None,
         anchor: GeoboxAnchor = AnchorEnum.EDGE,
         tol: float = 0.01,
@@ -101,7 +100,9 @@ class GeoBox:
 
         :param bbox: Bounding box in CRS units, lonlat is assumed when ``crs`` is not supplied
         :param crs: CRS of the bounding box (defaults to EPSG:4326)
-        :param shape: Span that many pixels.
+        :param shape:
+           Span that many pixels, if it's a single number then span that many pixels along the
+           longest dimension, other dimension will be computed to maintain roughly square pixels.
         :param resolution: Use specified resolution
         :param tight: Supplying ``tight=True`` turns off pixel snapping.
         :param anchor:
@@ -114,7 +115,7 @@ class GeoBox:
         :return:
            :py:class:`~odc.geo.geobox.GeoBox` that covers supplied bounding box.
         """
-        # pylint: disable=too-many-locals
+        # pylint: disable=too-many-locals, too-many-branches
 
         _snap: Optional[XY[float]] = None
 
@@ -133,6 +134,13 @@ class GeoBox:
         elif bbox.crs is None:
             bbox = BoundingBox(*bbox.bbox, crs=(crs or "epsg:4326"))
 
+        if isinstance(shape, (int, float)):
+            if bbox.aspect > 1:
+                resolution = bbox.span_x / shape
+            else:
+                resolution = bbox.span_y / shape
+            shape = None
+
         if resolution is not None:
             rx, ry = res_(resolution).xy
             if _snap is None:
@@ -165,10 +173,12 @@ class GeoBox:
     @staticmethod
     def from_geopolygon(
         geopolygon: Geometry,
-        resolution: SomeResolution,
+        resolution: Optional[SomeResolution] = None,
         crs: MaybeCRS = None,
         align: Optional[XY[float]] = None,
         *,
+        shape: Union[SomeShape, int, None] = None,
+        tight: bool = False,
         anchor: GeoboxAnchor = AnchorEnum.EDGE,
         tol: float = 0.01,
     ) -> "GeoBox":
@@ -178,7 +188,11 @@ class GeoBox:
         :param resolution:
            Either a single number or a :py:class:`~odc.geo.types.Resolution` object.
 
-        :param crs:
+        :param shape:
+           Span that many pixels, if it's a single number then span that many pixels along the
+           longest dimension, other dimension will be computed to maintain roughly square pixels.
+
+         :param crs:
            CRS to use, if different from the geopolygon
 
         :param align:
@@ -191,19 +205,32 @@ class GeoBox:
             Fraction of a pixel that can be ignored, defaults to 1/100. Bounding box of the output
             geobox is allowed to be smaller than supplied bounding box by that amount.
 
+        :param tight: Supplying ``tight=True`` turns off pixel snapping.
+
         """
-        resolution = res_(resolution)
         if align is not None:
             # support old-style "align", which is basically anchor but in CRS units
             ax, ay = align.xy
-            anchor = xy_(ax / abs(resolution.x), ay / abs(resolution.y))
+            if ax == 0 and ay == 0:
+                anchor = AnchorEnum.EDGE
+            else:
+                assert resolution is not None
+                resolution = res_(resolution)
+                anchor = xy_(ax / abs(resolution.x), ay / abs(resolution.y))
+
         if crs is None:
             crs = geopolygon.crs
         else:
             geopolygon = geopolygon.to_crs(crs)
 
         return GeoBox.from_bbox(
-            geopolygon.boundingbox, crs, resolution=resolution, anchor=anchor, tol=tol
+            geopolygon.boundingbox,
+            crs,
+            shape=shape,
+            resolution=resolution,
+            anchor=anchor,
+            tol=tol,
+            tight=tight,
         )
 
     def buffered(self, xbuff: float, ybuff: Optional[float] = None) -> "GeoBox":
@@ -312,6 +339,11 @@ class GeoBox:
         """Shape in pixels ``(height, width)``."""
         return self._shape
 
+    @property
+    def aspect(self) -> float:
+        """Aspect ratio (X/Y in pixel space)."""
+        return self._shape.aspect
+
     @property
     def crs(self) -> Optional[CRS]:
         """Coordinate Reference System of the GeoBox."""
@@ -328,8 +360,7 @@ class GeoBox:
     @property
     def resolution(self) -> Resolution:
         """Resolution, pixel size in CRS units."""
-        rx, _, _, _, ry, *_ = self._affine
-        return resxy_(rx, ry)
+        return resolution_from_affine(self._affine)
 
     @property
     def alignment(self) -> XY[float]:
@@ -384,11 +415,56 @@ class GeoBox:
         """GeoBox bounding box in the native CRS."""
         return BoundingBox.from_transform(self._shape, self._affine, crs=self._crs)
 
+    def map_bounds(
+        self, *args, **kw
+    ) -> Tuple[Tuple[float, float], Tuple[float, float]]:
+        """
+        Query bounds in folium/ipyleaflet style.
+
+        Returns SW, and NE corners in lat/lon order.
+        ``((lat_w, lon_s), (lat_e, lon_n))``.
+        """
+        return self.boundingbox.map_bounds(*args, **kw)
+
     def _reproject_resolution(self, npoints: int = 100):
         bbox = self.extent.boundingbox
         span = max(bbox.span_x, bbox.span_y)
         return span / npoints
 
+    def to_crs(
+        self,
+        crs: SomeCRS,
+        *,
+        resolution: Literal["auto", "fit", "same"] = "auto",
+        tight: bool = False,
+    ) -> "GeoBox":
+        """
+        Compute GeoBox covering the same region in a different projection.
+
+        :param crs:
+           Desired CRS of the output
+
+        :param resolution:
+
+           * "same" use exactly the same resolution as src
+           * "fit" use center pixel to determine scale change between the two
+           * | "auto" is to use the same resolution on the output if CRS units are the same
+             |  between the source and destination and otherwise use "fit"
+
+        :param tight:
+          By default output pixel grid is adjusted to align pixel edges to X/Y axis, suppling
+          ``tight=True`` produces unaligned geobox on the output.
+
+        :return:
+           Similar resolution, axis aligned geobox that fully encloses this one but in a different
+           projection.
+        """
+        # pylint: disable=import-outside-toplevel
+        # can't be up-top due to circular imports issues
+        from .overlap import compute_output_geobox
+
+        return compute_output_geobox(self, crs, resolution=resolution, tight=tight)
+
     def footprint(
         self, crs: SomeCRS, buffer: float = 0, npoints: int = 100
     ) -> Geometry:
@@ -509,13 +585,19 @@ class GeoBox:
         A = self._affine * Affine.scale(factor, factor)
         return GeoBox((ny, nx), A, self._crs)
 
-    def zoom_to(self, shape: SomeShape) -> "GeoBox":
+    def zoom_to(self, shape: Union[SomeShape, int, float]) -> "GeoBox":
         """
         Change GeoBox shape.
 
+        When supplied a single integer scale longest dimension to match that.
+
         :returns:
           GeoBox covering the same region but with different number of pixels and therefore resolution.
         """
+        if isinstance(shape, (int, float)):
+            nmax = max(*self._shape)
+            return self.zoom_out(nmax / shape)
+
         shape = shape_(shape)
         sy, sx = (N / float(n) for N, n in zip(self._shape, shape.shape))
         A = self._affine * Affine.scale(sx, sy)
