@@ -19,7 +19,7 @@ from .types import SomeShape, shape_
 
 CoordList = List[Tuple[float, float]]
 
-# pylint: disable=too-many-lines
+# pylint: disable=too-many-lines,too-many-public-methods
 
 
 class BoundingBox(Sequence[float]):
@@ -114,6 +114,11 @@ class BoundingBox(Sequence[float]):
         """Span of the bounding box along y axis."""
         return self.top - self.bottom
 
+    @property
+    def aspect(self) -> float:
+        """Aspect ratio."""
+        return self.span_x / self.span_y
+
     @property
     def width(self) -> int:
         """``int(span_x)``"""
@@ -142,7 +147,7 @@ class BoundingBox(Sequence[float]):
     @property
     def points(self) -> CoordList:
         """Extract four corners of the bounding box."""
-        x0, y0, x1, y1 = self
+        x0, y0, x1, y1 = self._box
         return list(itertools.product((x0, x1), (y0, y1)))
 
     def transform(self, transform: Affine) -> "BoundingBox":
@@ -157,6 +162,25 @@ class BoundingBox(Sequence[float]):
         yy = [y for _, y in pts]
         return BoundingBox(min(xx), min(yy), max(xx), max(yy), self._crs)
 
+    def to_crs(self, crs: SomeCRS, **kw) -> "BoundingBox":
+        """
+        Compute bounding box in other CRS.
+        """
+        return self.polygon.to_crs(crs, **kw).boundingbox
+
+    def map_bounds(self) -> Tuple[Tuple[float, float], Tuple[float, float]]:
+        """
+        Convert to bounds in folium/ipyleaflet style.
+
+        Returns SW, and NE corners in lat/lon order.
+        ``((lat_w, lon_s), (lat_e, lon_n))``.
+        """
+        if self._crs == "epsg:4326" or self._crs is None:
+            x0, y0, x1, y1 = self._box
+            return (y0, x0), (y1, x1)
+        x0, y0, x1, y1 = self.to_crs("epsg:4326")
+        return (y0, x0), (y1, x1)
+
     @property
     def polygon(self) -> "Geometry":
         return box(*self.bbox, self.crs)
@@ -286,7 +310,7 @@ class Geometry:
     by dropping the Z points.
     """
 
-    # pylint: disable=protected-access, too-many-public-methods
+    # pylint: disable=protected-access, multiple-statements
 
     def __init__(
         self,
@@ -311,148 +335,83 @@ class Geometry:
     def clone(self) -> "Geometry":
         return Geometry(self)
 
+    # fmt: off
     @wrap_shapely
-    def contains(self, other: "Geometry") -> bool:
-        return self.contains(other)
-
+    def contains(self, other: "Geometry") -> bool: return self.contains(other)
     @wrap_shapely
-    def crosses(self, other: "Geometry") -> bool:
-        return self.crosses(other)
-
+    def crosses(self, other: "Geometry") -> bool: return self.crosses(other)
     @wrap_shapely
-    def disjoint(self, other: "Geometry") -> bool:
-        return self.disjoint(other)
-
+    def disjoint(self, other: "Geometry") -> bool: return self.disjoint(other)
     @wrap_shapely
-    def intersects(self, other: "Geometry") -> bool:
-        return self.intersects(other)
-
+    def intersects(self, other: "Geometry") -> bool: return self.intersects(other)
     @wrap_shapely
-    def touches(self, other: "Geometry") -> bool:
-        return self.touches(other)
-
+    def touches(self, other: "Geometry") -> bool: return self.touches(other)
     @wrap_shapely
-    def within(self, other: "Geometry") -> bool:
-        return self.within(other)
-
+    def within(self, other: "Geometry") -> bool: return self.within(other)
     @wrap_shapely
-    def overlaps(self, other: "Geometry") -> bool:
-        return self.overlaps(other)
-
+    def overlaps(self, other: "Geometry") -> bool: return self.overlaps(other)
     @wrap_shapely
-    def difference(self, other: "Geometry") -> "Geometry":
-        return self.difference(other)
-
+    def difference(self, other: "Geometry") -> "Geometry": return self.difference(other)
     @wrap_shapely
-    def intersection(self, other: "Geometry") -> "Geometry":
-        return self.intersection(other)
-
+    def intersection(self, other: "Geometry") -> "Geometry": return self.intersection(other)
     @wrap_shapely
-    def symmetric_difference(self, other: "Geometry") -> "Geometry":
-        return self.symmetric_difference(other)
-
+    def symmetric_difference(self, other: "Geometry") -> "Geometry": return self.symmetric_difference(other)
     @wrap_shapely
-    def union(self, other: "Geometry") -> "Geometry":
-        return self.union(other)
-
+    def union(self, other: "Geometry") -> "Geometry": return self.union(other)
     @wrap_shapely
-    def __and__(self, other: "Geometry") -> "Geometry":
-        return self.__and__(other)
-
+    def __and__(self, other: "Geometry") -> "Geometry": return self.__and__(other)
     @wrap_shapely
-    def __or__(self, other: "Geometry") -> "Geometry":
-        return self.__or__(other)
-
+    def __or__(self, other: "Geometry") -> "Geometry": return self.__or__(other)
     @wrap_shapely
-    def __xor__(self, other: "Geometry") -> "Geometry":
-        return self.__xor__(other)
-
+    def __xor__(self, other: "Geometry") -> "Geometry": return self.__xor__(other)
     @wrap_shapely
-    def __sub__(self, other: "Geometry") -> "Geometry":
-        return self.__sub__(other)
+    def __sub__(self, other: "Geometry") -> "Geometry": return self.__sub__(other)
 
-    def svg(self, *args, **kw) -> str:
-        return self.geom.svg(*args, *kw)
+    def svg(self, *args, **kw) -> str: return self.geom.svg(*args, *kw)
 
-    def _repr_svg_(self) -> str:
-        return self.geom._repr_svg_()
+    def _repr_svg_(self) -> str: return self.geom._repr_svg_()
 
     @property
-    def type(self) -> str:
-        return self.geom.type
-
+    def type(self) -> str: return self.geom.type
     @property
-    def is_empty(self) -> bool:
-        return self.geom.is_empty
-
+    def is_empty(self) -> bool: return self.geom.is_empty
     @property
-    def is_valid(self) -> bool:
-        return self.geom.is_valid
-
+    def is_valid(self) -> bool: return self.geom.is_valid
     @property
-    def is_ring(self) -> bool:
-        return self.geom.is_ring
-
+    def is_ring(self) -> bool: return self.geom.is_ring
     @property
-    def boundary(self) -> "Geometry":
-        return Geometry(self.geom.boundary, self.crs)
-
+    def boundary(self) -> "Geometry": return Geometry(self.geom.boundary, self.crs)
     @property
-    def exterior(self) -> "Geometry":
-        return Geometry(self.geom.exterior, self.crs)
-
+    def exterior(self) -> "Geometry": return Geometry(self.geom.exterior, self.crs)
     @property
-    def interiors(self) -> List["Geometry"]:
-        return [Geometry(g, self.crs) for g in self.geom.interiors]
-
+    def interiors(self) -> List["Geometry"]: return [Geometry(g, self.crs) for g in self.geom.interiors]
     @property
-    def centroid(self) -> "Geometry":
-        return Geometry(self.geom.centroid, self.crs)
-
+    def centroid(self) -> "Geometry": return Geometry(self.geom.centroid, self.crs)
     @property
-    def coords(self) -> CoordList:
-        return list(self.geom.coords)
-
+    def coords(self) -> CoordList: return list(self.geom.coords)
     @property
-    def points(self) -> CoordList:
-        return self.coords
-
+    def points(self) -> CoordList: return self.coords
     @property
-    def length(self) -> float:
-        return self.geom.length
-
+    def length(self) -> float: return self.geom.length
     @property
-    def area(self) -> float:
-        return self.geom.area
-
+    def area(self) -> float: return self.geom.area
     @property
-    def xy(self) -> Tuple[array.array, array.array]:
-        return self.geom.xy
-
+    def xy(self) -> Tuple[array.array, array.array]: return self.geom.xy
     @property
-    def convex_hull(self) -> "Geometry":
-        return Geometry(self.geom.convex_hull, self.crs)
-
+    def convex_hull(self) -> "Geometry": return Geometry(self.geom.convex_hull, self.crs)
     @property
-    def envelope(self) -> "Geometry":
-        return Geometry(self.geom.envelope, self.crs)
-
+    def envelope(self) -> "Geometry": return Geometry(self.geom.envelope, self.crs)
     @property
     def boundingbox(self) -> BoundingBox:
         minx, miny, maxx, maxy = self.geom.bounds
         return BoundingBox(left=minx, right=maxx, bottom=miny, top=maxy, crs=self.crs)
-
     @property
-    def wkt(self) -> str:
-        return self.geom.wkt
-
+    def wkt(self) -> str: return self.geom.wkt
     @property
-    def __array_interface__(self):
-        return self.geom.__array_interface__
-
+    def __array_interface__(self): return self.geom.__array_interface__
     @property
-    def __geo_interface__(self):
-        return self.geom.__geo_interface__
+    def __geo_interface__(self): return self.geom.__geo_interface__
+    # fmt: on
 
     @property
     def json(self):
